@@ -9,8 +9,11 @@ from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, Decr
 from users.serializers import UserSerializer
 from django.db.models import Q
 from firebase_admin import db
-from STiiiCK.settings import DEFAULT_APP, FIREBASE_REF, FIREBASE_REF_DEV, AUTH_USER_MODEL, GROUP_MODEL
+from django.conf import settings
 
+DEFAULT_APP = settings.DEFAULT_APP
+FIREBASE_REF = settings.FIREBASE_REF
+FIREBASE_REF_DEV = settings.FIREBASE_REF_DEV
 User = AUTH_USER_MODEL
 Group = GROUP_MODEL
 
